==> netsurf-1.0-src.tar.gz: netsurf/riscos/palettes.c <==
/*
 * This file is part of NetSurf, http://netsurf-browser.org/
 * Licensed under the GNU General Public License,
 *                http://www.opensource.org/licenses/gpl-license
 * Copyright 2006 Adrian Lees <adrianl@users.sourceforge.net>
 */

/** \file
 * Palette definitions for sprites
 */

#include "netsurf/riscos/palettes.h"


const os_colour default_palette1[] =
{
  0xffffff00, 0xffffff00,
  0x00000000, 0x00000000
};


const os_colour default_palette2[] =
{
  0xffffff00, 0xffffff00,
  0xbbbbbb00, 0xbbbbbb00,
  0x77777700, 0x77777700,
  0x00000000, 0x00000000
};


const os_colour wimp_palette[] =
{
  0xffffff00, 0xffffff00,
  0xdddddd00, 0xdddddd00,
  0xbbbbbb00, 0xbbbbbb00,
  0x99999900, 0x99999900,
  0x77777700, 0x77777700,
  0x55555500, 0x55555500,
  0x33333300, 0x33333300,
  0x00000000, 0x00000000,
  0x99440000, 0x99440000,
  0x00eeee00, 0x00eeee00,
  0x00cc0000, 0x00cc0000,
  0x0000dd00, 0x0000dd00,
  0xbbeeee00, 0xbbeeee00,
  0x00885500, 0x00885500,
  0x00bbff00, 0x00bbff00,
  0xffbb0000, 0xffbb0000
};


const os_colour default_palette8[] =
{
  0x00000010, 0x00000010,
  0x11111110, 0x11111110,
  0x22222210, 0x22222210,
  0x33333310, 0x33333310,
  0x00004410, 0x00004410,
  0x11115510, 0x11115510,
  0x22226610, 0x22226610,
  0x33337710, 0x33337710,
  0x44000010, 0x44000010,
  0x55111110, 0x55111110,
  0x66222210, 0x66222210,
  0x77333310, 0x77333310,
  0x44004410, 0x44004410,
  0x55115510, 0x55115510,
  0x66226610, 0x66226610,
  0x77337710, 0x77337710,
  0x00008810, 0x00008810,
  0x11119910, 0x11119910,
  0x2222AA10, 0x2222AA10,
  0x3333BB10, 0x3333BB10,
  0x0000CC10, 0x0000CC10,
  0x1111DD10, 0x1111DD10,
  0x2222EE10, 0x2222EE10,
  0x3333FF10, 0x3333FF10,
  0x44008810, 0x44008810,
  0x55119910, 0x55119910,
  0x6622AA10, 0x6622AA10,
  0x7733BB10, 0x7733BB10,
  0x4400CC10, 0x4400CC10,
  0x5511DD10, 0x5511DD10,
  0x6622EE10, 0x6622EE10,
  0x7733FF10, 0x7733FF10,
  0x00440010, 0x00440010,
  0x11551110, 0x11551110,
  0x22662210, 0x22662210,
  0x33773310, 0x33773310,
  0x00444410, 0x00444410,
  0x11555510, 0x11555510,
  0x22666610, 0x22666610,
  0x33777710, 0x33777710,
  0x44440010, 0x44440010,
  0x55551110, 0x55551110,
  0x66662210, 0x66662210,
  0x77773310, 0x77773310,
  0x44444410, 0x44444410,
  0x55555510, 0x55555510,
  0x66666610, 0x66666610,
  0x77777710, 0x77777710,
  0x00448810, 0x00448810,
  0x11559910, 0x11559910,
  0x2266AA10, 0x2266AA10,
  0x3377BB10, 0x3377BB10,
  0x0044CC10, 0x0044CC10,
  0x1155DD10, 0x1155DD10,
  0x2266EE10, 0x2266EE10,
  0x3377FF10, 0x3377FF10,
  0x44448810, 0x44448810,
  0x55559910, 0x55559910,
  0x6666AA10, 0x6666AA10,
  0x7777BB10, 0x7777BB10,
  0x4444CC10, 0x4444CC10,
  0x5555DD10, 0x5555DD10,
  0x6666EE10, 0x6666EE10,
  0x7777FF10, 0x7777FF10,
  0x00880010, 0x00880010,
  0x11991110, 0x11991110,
  0x22AA2210, 0x22AA2210,
  0x33BB3310, 0x33BB3310,
  0x00884410, 0x00884410,
  0x11995510, 0x11995510,
  0x22AA6610, 0x22AA6610,
  0x33BB7710, 0x33BB7710,
  0x44880010, 0x44880010,
  0x55991110, 0x55991110,
  0x66AA2210, 0x66AA2210,
  0x77BB3310, 0x77BB3310,
  0x44884410, 0x44884410,
  0x55995510, 0x55995510,
  0x66AA6610, 0x66AA6610,
  0x77BB7710, 0x77BB7710,
  0x00888810, 0x00888810,
  0x11999910, 0x11999910,
  0x22AAAA10, 0x22AAAA10,
  0x33BBBB10, 0x33BBBB10,
  0x0088CC10, 0x0088CC10,
  0x1199DD10, 0x1199DD10,
  0x22AAEE10, 0x22AAEE10,
  0x33BBFF10, 0x33BBFF10,
  0x44888810, 0x44888810,
  0x55999910, 0x55999910,
  0x66AAAA10, 0x66AAAA10,
  0x77BBBB10, 0x77BBBB10,
  0x4488CC10, 0x4488CC10,
  0x5599DD10, 0x5599DD10,
  0x66AAEE10, 0x66AAEE10,
  0x77BBFF10, 0x77BBFF10,
  0x00CC0010, 0x00CC0010,
  0x11DD1110, 0x11DD1110,
  0x22EE2210, 0x22EE2210,
  0x33FF3310, 0x33FF3310,
  0x00CC4410, 0x00CC4410,
  0x11DD5510, 0x11DD5510,
  0x22EE6610, 0x22EE6610,
  0x33FF7710, 0x33FF7710,
  0x44CC0010, 0x44CC0010,
  0x55DD1110, 0x55DD1110,
  0x66EE2210, 0x66EE2210,
  0x77FF3310, 0x77FF3310,
  0x44CC4410, 0x44CC4410,
  0x55DD5510, 0x55DD5510,
  0x66EE6610, 0x66EE6610,
  0x77FF7710, 0x77FF7710,
  0x00CC8810, 0x00CC8810,
  0x11DD9910, 0x11DD9910,
  0x22EEAA10, 0x22EEAA10,
  0x33FFBB10, 0x33FFBB10,
  0x00CCCC10, 0x00CCCC10,
  0x11DDDD10, 0x11DDDD10,
  0x22EEEE10, 0x22EEEE10,
  0x33FFFF10, 0x33FFFF10,
  0x44CC8810, 0x44CC8810,
  0x55DD9910, 0x55DD9910,
  0x66EEAA10, 0x66EEAA10,
  0x77FFBB10, 0x77FFBB10,
  0x44CCCC10, 0x44CCCC10,
  0x55DDDD10, 0x55DDDD10,
  0x66EEEE10, 0x66EEEE10,
  0x77FFFF10, 0x77FFFF10,
  0x88000010, 0x88000010,
  0x99111110, 0x99111110,
  0xAA222210, 0xAA222210,
  0xBB333310, 0xBB333310,
  0x88004410, 0x88004410,
  0x99115510, 0x99115510,
  0xAA226610, 0xAA226610,
  0xBB337710, 0xBB337710,
  0xCC000010, 0xCC000010,
  0xDD111110, 0xDD111110,
  0xEE222210, 0xEE222210,
  0xFF333310, 0xFF333310,
  0xCC004410, 0xCC004410,
  0xDD115510, 0xDD115510,
  0xEE226610, 0xEE226610,
  0xFF337710, 0xFF337710,
  0x88008810, 0x88008810,
  0x99119910, 0x99119910,
  0xAA22AA10, 0xAA22AA10,
  0xBB33BB10, 0xBB33BB10,
  0x8800CC10, 0x8800CC10,
  0x9911DD10, 0x9911DD10,
  0xAA22EE10, 0xAA22EE10,
  0xBB33FF10, 0xBB33FF10,
  0xCC008810, 0xCC008810,
  0xDD119910, 0xDD119910,
  0xEE22AA10, 0xEE22AA10,
  0xFF33BB10, 0xFF33BB10,
  0xCC00CC10, 0xCC00CC10,
  0xDD11DD10, 0xDD11DD10,
  0xEE22EE10, 0xEE22EE10,
  0xFF33FF10, 0xFF33FF10,
  0x88440010, 0x88440010,
  0x99551110, 0x99551110,
  0xAA662210, 0xAA662210,
  0xBB773310, 0xBB773310,
  0x88444410, 0x88444410,
  0x99555510, 0x99555510,
  0xAA666610, 0xAA666610,
  0xBB777710, 0xBB777710,
  0xCC440010, 0xCC440010,
  0xDD551110, 0xDD551110,
  0xEE662210, 0xEE662210,
  0xFF773310, 0xFF773310,
  0xCC444410, 0xCC444410,
  0xDD555510, 0xDD555510,
  0xEE666610, 0xEE666610,
  0xFF777710, 0xFF777710,
  0x88448810, 0x88448810,
  0x99559910, 0x99559910,
  0xAA66AA10, 0xAA66AA10,
  0xBB77BB10, 0xBB77BB10,
  0x8844CC10, 0x8844CC10,
  0x9955DD10, 0x9955DD10,
  0xAA66EE10, 0xAA66EE10,
  0xBB77FF10, 0xBB77FF10,
  0xCC448810, 0xCC448810,
  0xDD559910, 0xDD559910,
  0xEE66AA10, 0xEE66AA10,
  0xFF77BB10, 0xFF77BB10,
  0xCC44CC10, 0xCC44CC10,
  0xDD55DD10, 0xDD55DD10,
  0xEE66EE10, 0xEE66EE10,
  0xFF77FF10, 0xFF77FF10,
  0x88880010, 0x88880010,
  0x99991110, 0x99991110,
  0xAAAA2210, 0xAAAA2210,
  0xBBBB3310, 0xBBBB3310,
  0x88884410, 0x88884410,
  0x99995510, 0x99995510,
  0xAAAA6610, 0xAAAA6610,
  0xBBBB7710, 0xBBBB7710,
  0xCC880010, 0xCC880010,
  0xDD991110, 0xDD991110,
  0xEEAA2210, 0xEEAA2210,
  0xFFBB3310, 0xFFBB3310,
  0xCC884410, 0xCC884410,
  0xDD995510, 0xDD995510,
  0xEEAA6610, 0xEEAA6610,
  0xFFBB7710, 0xFFBB7710,
  0x88888810, 0x88888810,
  0x99999910, 0x99999910,
  0xAAAAAA10, 0xAAAAAA10,
  0xBBBBBB10, 0xBBBBBB10,
  0x8888CC10, 0x8888CC10,
  0x9999DD10, 0x9999DD10,
  0xAAAAEE10, 0xAAAAEE10,
  0xBBBBFF10, 0xBBBBFF10,
  0xCC888810, 0xCC888810,
  0xDD999910, 0xDD999910,
  0xEEAAAA10, 0xEEAAAA10,
  0xFFBBBB10, 0xFFBBBB10,
  0xCC88CC10, 0xCC88CC10,
  0xDD99DD10, 0xDD99DD10,
  0xEEAAEE10, 0xEEAAEE10,
  0xFFBBFF10, 0xFFBBFF10,
  0x88CC0010, 0x88CC0010,
  0x99DD1110, 0x99DD1110,
  0xAAEE2210, 0xAAEE2210,
  0xBBFF3310, 0xBBFF3310,
  0x88CC4410, 0x88CC4410,
  0x99DD5510, 0x99DD5510,
  0xAAEE6610, 0xAAEE6610,
  0xBBFF7710, 0xBBFF7710,
  0xCCCC0010, 0xCCCC0010,
  0xDDDD1110, 0xDDDD1110,
  0xEEEE2210, 0xEEEE2210,
  0xFFFF3310, 0xFFFF3310,
  0xCCCC4410, 0xCCCC4410,
  0xDDDD5510, 0xDDDD5510,
  0xEEEE6610, 0xEEEE6610,
  0xFFFF7710, 0xFFFF7710,
  0x88CC8810, 0x88CC8810,
  0x99DD9910, 0x99DD9910,
  0xAAEEAA10, 0xAAEEAA10,
  0xBBFFBB10, 0xBBFFBB10,
  0x88CCCC10, 0x88CCCC10,
  0x99DDDD10, 0x99DDDD10,
  0xAAEEEE10, 0xAAEEEE10,
  0xBBFFFF10, 0xBBFFFF10,
  0xCCCC8810, 0xCCCC8810,
  0xDDDD9910, 0xDDDD9910,
  0xEEEEAA10, 0xEEEEAA10,
  0xFFFFBB10, 0xFFFFBB10,
  0xCCCCCC10, 0xCCCCCC10,
  0xDDDDDD10, 0xDDDDDD10,
  0xEEEEEE10, 0xEEEEEE10,
  0xFFFFFF10, 0xFFFFFF10
};

==> netsurf-2.1-src.tar.gz: netsurf/riscos/palettes.c <==
/*
 * Copyright 2006 Adrian Lees <adrianl@users.sourceforge.net>
 *
 * This file is part of NetSurf, http://www.netsurf-browser.org/
 *
 * NetSurf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * NetSurf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/** \file
 * Palette definitions for sprites
 */

#include "riscos/palettes.h"


const os_colour default_palette1[] =
{
  0xffffff00, 0xffffff00,
  0x00000000, 0x00000000
};


const os_colour default_palette2[] =
{
  0xffffff00, 0xffffff00,
  0xbbbbbb00, 0xbbbbbb00,
  0x77777700, 0x77777700,
  0x00000000, 0x00000000
};


const os_colour wimp_palette[] =
{
  0xffffff00, 0xffffff00,
  0xdddddd00, 0xdddddd00,
  0xbbbbbb00, 0xbbbbbb00,
  0x99999900, 0x99999900,
  0x77777700, 0x77777700,
  0x55555500, 0x55555500,
  0x33333300, 0x33333300,
  0x00000000, 0x00000000,
  0x99440000, 0x99440000,
  0x00eeee00, 0x00eeee00,
  0x00cc0000, 0x00cc0000,
  0x0000dd00, 0x0000dd00,
  0xbbeeee00, 0xbbeeee00,
  0x00885500, 0x00885500,
  0x00bbff00, 0x00bbff00,
  0xffbb0000, 0xffbb0000
};


const os_colour default_palette8[] =
{
  0x00000010, 0x00000010,
  0x11111110, 0x11111110,
  0x22222210, 0x22222210,
  0x33333310, 0x33333310,
  0x00004410, 0x00004410,
  0x11115510, 0x11115510,
  0x22226610, 0x22226610,
  0x33337710, 0x33337710,
  0x44000010, 0x44000010,
  0x55111110, 0x55111110,
  0x66222210, 0x66222210,
  0x77333310, 0x77333310,
  0x44004410, 0x44004410,
  0x55115510, 0x55115510,
  0x66226610, 0x66226610,
  0x77337710, 0x77337710,
  0x00008810, 0x00008810,
  0x11119910, 0x11119910,
  0x2222AA10, 0x2222AA10,
  0x3333BB10, 0x3333BB10,
  0x0000CC10, 0x0000CC10,
  0x1111DD10, 0x1111DD10,
  0x2222EE10, 0x2222EE10,
  0x3333FF10, 0x3333FF10,
  0x44008810, 0x44008810,
  0x55119910, 0x55119910,
  0x6622AA10, 0x6622AA10,
  0x7733BB10, 0x7733BB10,
  0x4400CC10, 0x4400CC10,
  0x5511DD10, 0x5511DD10,
  0x6622EE10, 0x6622EE10,
  0x7733FF10, 0x7733FF10,
  0x00440010, 0x00440010,
  0x11551110, 0x11551110,
  0x22662210, 0x22662210,
  0x33773310, 0x33773310,
  0x00444410, 0x00444410,
  0x11555510, 0x11555510,
  0x22666610, 0x22666610,
  0x33777710, 0x33777710,
  0x44440010, 0x44440010,
  0x55551110, 0x55551110,
  0x66662210, 0x66662210,
  0x77773310, 0x77773310,
  0x44444410, 0x44444410,
  0x55555510, 0x55555510,
  0x66666610, 0x66666610,
  0x77777710, 0x77777710,
  0x00448810, 0x00448810,
  0x11559910, 0x11559910,
  0x2266AA10, 0x2266AA10,
  0x3377BB10, 0x3377BB10,
  0x0044CC10, 0x0044CC10,
  0x1155DD10, 0x1155DD10,
  0x2266EE10, 0x2266EE10,
  0x3377FF10, 0x3377FF10,
  0x44448810, 0x44448810,
  0x55559910, 0x55559910,
  0x6666AA10, 0x6666AA10,
  0x7777BB10, 0x7777BB10,
  0x4444CC10, 0x4444CC10,
  0x5555DD10, 0x5555DD10,
  0x6666EE10, 0x6666EE10,
  0x7777FF10, 0x7777FF10,
  0x00880010, 0x00880010,
  0x11991110, 0x11991110,
  0x22AA2210, 0x22AA2210,
  0x33BB3310, 0x33BB3310,
  0x00884410, 0x00884410,
  0x11995510, 0x11995510,
  0x22AA6610, 0x22AA6610,
  0x33BB7710, 0x33BB7710,
  0x44880010, 0x44880010,
  0x55991110, 0x55991110,
  0x66AA2210, 0x66AA2210,
  0x77BB3310, 0x77BB3310,
  0x44884410, 0x44884410,
  0x55995510, 0x55995510,
  0x66AA6610, 0x66AA6610,
  0x77BB7710, 0x77BB7710,
  0x00888810, 0x00888810,
  0x11999910, 0x11999910,
  0x22AAAA10, 0x22AAAA10,
  0x33BBBB10, 0x33BBBB10,
  0x0088CC10, 0x0088CC10,
  0x1199DD10, 0x1199DD10,
  0x22AAEE10, 0x22AAEE10,
  0x33BBFF10, 0x33BBFF10,
  0x44888810, 0x44888810,
  0x55999910, 0x55999910,
  0x66AAAA10, 0x66AAAA10,
  0x77BBBB10, 0x77BBBB10,
  0x4488CC10, 0x4488CC10,
  0x5599DD10, 0x5599DD10,
  0x66AAEE10, 0x66AAEE10,
  0x77BBFF10, 0x77BBFF10,
  0x00CC0010, 0x00CC0010,
  0x11DD1110, 0x11DD1110,
  0x22EE2210, 0x22EE2210,
  0x33FF3310, 0x33FF3310,
  0x00CC4410, 0x00CC4410,
  0x11DD5510, 0x11DD5510,
  0x22EE6610, 0x22EE6610,
  0x33FF7710, 0x33FF7710,
  0x44CC0010, 0x44CC0010,
  0x55DD1110, 0x55DD1110,
  0x66EE2210, 0x66EE2210,
  0x77FF3310, 0x77FF3310,
  0x44CC4410, 0x44CC4410,
  0x55DD5510, 0x55DD5510,
  0x66EE6610, 0x66EE6610,
  0x77FF7710, 0x77FF7710,
  0x00CC8810, 0x00CC8810,
  0x11DD9910, 0x11DD9910,
  0x22EEAA10, 0x22EEAA10,
  0x33FFBB10, 0x33FFBB10,
  0x00CCCC10, 0x00CCCC10,
  0x11DDDD10, 0x11DDDD10,
  0x22EEEE10, 0x22EEEE10,
  0x33FFFF10, 0x33FFFF10,
  0x44CC8810, 0x44CC8810,
  0x55DD9910, 0x55DD9910,
  0x66EEAA10, 0x66EEAA10,
  0x77FFBB10, 0x77FFBB10,
  0x44CCCC10, 0x44CCCC10,
  0x55DDDD10, 0x55DDDD10,
  0x66EEEE10, 0x66EEEE10,
  0x77FFFF10, 0x77FFFF10,
  0x88000010, 0x88000010,
  0x99111110, 0x99111110,
  0xAA222210, 0xAA222210,
  0xBB333310, 0xBB333310,
  0x88004410, 0x88004410,
  0x99115510, 0x99115510,
  0xAA226610, 0xAA226610,
  0xBB337710, 0xBB337710,
  0xCC000010, 0xCC000010,
  0xDD111110, 0xDD111110,
  0xEE222210, 0xEE222210,
  0xFF333310, 0xFF333310,
  0xCC004410, 0xCC004410,
  0xDD115510, 0xDD115510,
  0xEE226610, 0xEE226610,
  0xFF337710, 0xFF337710,
  0x88008810, 0x88008810,
  0x99119910, 0x99119910,
  0xAA22AA10, 0xAA22AA10,
  0xBB33BB10, 0xBB33BB10,
  0x8800CC10, 0x8800CC10,
  0x9911DD10, 0x9911DD10,
  0xAA22EE10, 0xAA22EE10,
  0xBB33FF10, 0xBB33FF10,
  0xCC008810, 0xCC008810,
  0xDD119910, 0xDD119910,
  0xEE22AA10, 0xEE22AA10,
  0xFF33BB10, 0xFF33BB10,
  0xCC00CC10, 0xCC00CC10,
  0xDD11DD10, 0xDD11DD10,
  0xEE22EE10, 0xEE22EE10,
  0xFF33FF10, 0xFF33FF10,
  0x88440010, 0x88440010,
  0x99551110, 0x99551110,
  0xAA662210, 0xAA662210,
  0xBB773310, 0xBB773310,
  0x88444410, 0x88444410,
  0x99555510, 0x99555510,
  0xAA666610, 0xAA666610,
  0xBB777710, 0xBB777710,
  0xCC440010, 0xCC440010,
  0xDD551110, 0xDD551110,
  0xEE662210, 0xEE662210,
  0xFF773310, 0xFF773310,
  0xCC444410, 0xCC444410,
  0xDD555510, 0xDD555510,
  0xEE666610, 0xEE666610,
  0xFF777710, 0xFF777710,
  0x88448810, 0x88448810,
  0x99559910, 0x99559910,
  0xAA66AA10, 0xAA66AA10,
  0xBB77BB10, 0xBB77BB10,
  0x8844CC10, 0x8844CC10,
  0x9955DD10, 0x9955DD10,
  0xAA66EE10, 0xAA66EE10,
  0xBB77FF10, 0xBB77FF10,
  0xCC448810, 0xCC448810,
  0xDD559910, 0xDD559910,
  0xEE66AA10, 0xEE66AA10,
  0xFF77BB10, 0xFF77BB10,
  0xCC44CC10, 0xCC44CC10,
  0xDD55DD10, 0xDD55DD10,
  0xEE66EE10, 0xEE66EE10,
  0xFF77FF10, 0xFF77FF10,
  0x88880010, 0x88880010,
  0x99991110, 0x99991110,
  0xAAAA2210, 0xAAAA2210,
  0xBBBB3310, 0xBBBB3310,
  0x88884410, 0x88884410,
  0x99995510, 0x99995510,
  0xAAAA6610, 0xAAAA6610,
  0xBBBB7710, 0xBBBB7710,
  0xCC880010, 0xCC880010,
  0xDD991110, 0xDD991110,
  0xEEAA2210, 0xEEAA2210,
  0xFFBB3310, 0xFFBB3310,
  0xCC884410, 0xCC884410,
  0xDD995510, 0xDD995510,
  0xEEAA6610, 0xEEAA6610,
  0xFFBB7710, 0xFFBB7710,
  0x88888810, 0x88888810,
  0x99999910, 0x99999910,
  0xAAAAAA10, 0xAAAAAA10,
  0xBBBBBB10, 0xBBBBBB10,
  0x8888CC10, 0x8888CC10,
  0x9999DD10, 0x9999DD10,
  0xAAAAEE10, 0xAAAAEE10,
  0xBBBBFF10, 0xBBBBFF10,
  0xCC888810, 0xCC888810,
  0xDD999910, 0xDD999910,
  0xEEAAAA10, 0xEEAAAA10,
  0xFFBBBB10, 0xFFBBBB10,
  0xCC88CC10, 0xCC88CC10,
  0xDD99DD10, 0xDD99DD10,
  0xEEAAEE10, 0xEEAAEE10,
  0xFFBBFF10, 0xFFBBFF10,
  0x88CC0010, 0x88CC0010,
  0x99DD1110, 0x99DD1110,
  0xAAEE2210, 0xAAEE2210,
  0xBBFF3310, 0xBBFF3310,
  0x88CC4410, 0x88CC4410,
  0x99DD5510, 0x99DD5510,
  0xAAEE6610, 0xAAEE6610,
  0xBBFF7710, 0xBBFF7710,
  0xCCCC0010, 0xCCCC0010,
  0xDDDD1110, 0xDDDD1110,
  0xEEEE2210, 0xEEEE2210,
  0xFFFF3310, 0xFFFF3310,
  0xCCCC4410, 0xCCCC4410,
  0xDDDD5510, 0xDDDD5510,
  0xEEEE6610, 0xEEEE6610,
  0xFFFF7710, 0xFFFF7710,
  0x88CC8810, 0x88CC8810,
  0x99DD9910, 0x99DD9910,
  0xAAEEAA10, 0xAAEEAA10,
  0xBBFFBB10, 0xBBFFBB10,
  0x88CCCC10, 0x88CCCC10,
  0x99DDDD10, 0x99DDDD10,
  0xAAEEEE10, 0xAAEEEE10,
  0xBBFFFF10, 0xBBFFFF10,
  0xCCCC8810, 0xCCCC8810,
  0xDDDD9910, 0xDDDD9910,
  0xEEEEAA10, 0xEEEEAA10,
  0xFFFFBB10, 0xFFFFBB10,
  0xCCCCCC10, 0xCCCCCC10,
  0xDDDDDD10, 0xDDDDDD10,
  0xEEEEEE10, 0xEEEEEE10,
  0xFFFFFF10, 0xFFFFFF10
};
